@@ -46,7 +46,7 @@ namespace manager
 
 Base::Base(const std::shared_ptr<Registry::Impl>& registry)
     : registry_{registry}
-    , allApplicationJobs_{"application-legacy", "application-snap"}
+    , allApplicationJobs_{"application-click", "application-legacy", "application-snap"}
 {
 }
 
@@ -782,7 +782,7 @@ void Base::focus()
     }
     else
     {
-        g_debug("Emmitted 'LomiriFocusRequest' to DBus");
+        g_debug("Emitted 'LomiriFocusRequest' to DBus");
     }
 }
 
@@ -867,7 +867,7 @@ void Base::pidListToDbus(const std::shared_ptr<Registry::Impl>& reg,
     }
     else
     {
-        g_debug("Emmitted '%s' to DBus", signal.c_str());
+        g_debug("Emitted '%s' to DBus", signal.c_str());
     }
 }
 
@@ -883,7 +883,7 @@ void Base::setOomAdjustment(const oom::Score score)
 
 /** Figures out the path to the primary PID of the application and
     then reads its OOM adjustment file. */
-const oom::Score Base::getOomAdjustment()
+oom::Score Base::getOomAdjustment()
 {
     auto pid = primaryPid();
     if (pid == 0)
@@ -1022,7 +1022,7 @@ void Base::oomValueToPidHelper(pid_t pid, const oom::Score oomvalue)
     std::string pidstr = std::to_string(pid);
     std::array<const char*, 4> args = {OOM_HELPER, pidstr.c_str(), oomstr.c_str(), nullptr};
 
-    g_debug("Excuting OOM Helper (pid: %d, score: %d): %s", int(pid), int(oomvalue),
+    g_debug("Executing OOM Helper (pid: %d, score: %d): %s", int(pid), int(oomvalue),
             std::accumulate(args.begin(), args.end(), std::string{}, [](const std::string& instr,
                                                                         const char* output) -> std::string {
                 if (instr.empty())
