@@ -607,11 +607,7 @@ std::shared_ptr<Application::Instance> SystemD::launch(
 
             /* If we're in Lomiri we don't want to pass it's platform, we want
              * an application platform. */
-            if (findEnv("QT_QPA_PLATFORM", env) == "mirserver" || findEnv("QT_QPA_PLATFORM", env) == "lomirimirclient")
-            {
-                removeEnv("QT_QPA_PLATFORM", env);
-                env.emplace_back(std::make_pair("QT_QPA_PLATFORM", "wayland"));
-            }
+            removeEnv("QT_QPA_PLATFORM", env);
         }
 
         /* Mir socket if we don't have one in our env */
